@@ -231,6 +231,14 @@ impl Drop for ElectrsD {
     }
 }
 
+impl std::fmt::Display for Error {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "{:?}", self)
+    }
+}
+
+impl std::error::Error for Error {}
+
 impl From<std::io::Error> for Error {
     fn from(e: std::io::Error) -> Self {
         Error::Io(e)
@@ -325,7 +333,7 @@ mod test {
 
     fn init() -> (String, String) {
         let _ = env_logger::try_init();
-        let bitcoind_exe_path = if let Some(downloaded_exe_path) = bitcoind::downloaded_exe_path() {
+        let bitcoind_exe_path = if let Ok(downloaded_exe_path) = bitcoind::downloaded_exe_path() {
             downloaded_exe_path
         } else {
             env::var("BITCOIND_EXE").expect(
